using System;
using System.Collections;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Windows.Forms;

namespace MigraDoc.Rendering.Forms
{
  /// <summary>
  /// 
  /// </summary>
  public class PagePreview : System.Windows.Forms.UserControl
  {
    private PdfSharp.Forms.PagePreview preview;
    private System.ComponentModel.Container components = null;

    public PagePreview()
    {
      InitializeComponent();
    }

    /// <summary> 
    /// Clean up any resources being used.
    /// </summary>
    protected override void Dispose(bool disposing)
    {
      if (disposing)
      {
        if (components != null)
          components.Dispose();
      }
      base.Dispose(disposing);
    }

    [DefaultValue((int)BorderStyle.Fixed3D), Description("Determines the style of the border."), Category("Preview Properties")]
#if NET_1_1
    public BorderStyle BorderStyle
#endif
#if NET_2_0
    public new BorderStyle BorderStyle
#endif
    {
      get { return this.preview.BorderStyle; }
      set { this.preview.BorderStyle = value; }
    }

    /// <summary>
    /// Gets or sets a ddl string or file.
    /// </summary>
    public string Ddl
    {
      get { return ddl; }
      set
      {
        ddl = value;
        DdlUpdated();
      }
    }
    string ddl;

    /// <summary>
    /// Gets or sets the current page.
    /// </summary>
    public int Page
    {
      get { return page; }
      set
      {
        if (this.preview != null)
        {
          page = value;
          this.preview.Page = value;
        }
        else
          page = -1;
      }
    }
    int page;

    /// <summary>
    /// Gets the number of pages.
    /// </summary>
    public int PageCount
    {
      get { return this.preview.PreviewRenderer.PageCount; }
    }

    /// <summary>
    /// Goes to the first page.
    /// </summary>
    public void FirstPage()
    {
      this.preview.Page = this.page = 1;
    }

    /// <summary>
    /// Goes to the last page.
    /// </summary>
    public void LastPage()
    {
      if (page != PageCount)
        this.preview.Page = this.page = PageCount;
    }

    /// <summary>
    /// Goes to the next page.
    /// </summary>
    public void NextPage()
    {
      if (page < PageCount)
        this.preview.Page = ++this.page;
    }

    /// <summary>
    /// Goes to the previous page.
    /// </summary>
    public void PrevPage()
    {
      if (page > 1)
        this.preview.Page = --this.page;
    }

    /// <summary>
    /// Gets or sets the working directory.
    /// </summary>
    public string WorkingDirectory
    {
      get
      {
        return this.workingDirectory;
      }
      set
      {
        this.workingDirectory = value;
      }
    }
    string workingDirectory = "";

    /// <summary>
    /// Called when the Ddl property has changed.
    /// </summary>
    void DdlUpdated()
    {
      if (this.job != null)
        this.job.Dispose();

      if (this.ddl == null || this.ddl == "")
        return;

      this.job = new PrintJob();
      this.job.Type = JobType.Standard;
      this.job.Ddl = this.ddl;
      this.job.WorkingDirectory = this.workingDirectory;
      this.job.InitDocument();
      this.preview = this.job.GetPreview(this.Handle);
      this.previewHandle = this.preview.Hwnd;

      if (this.preview != null)
        this.preview.Page = 1;
    }

    /// <summary>
    /// Gets or sets a predefined zoom factor.
    /// </summary>
    [DefaultValue((int)Zoom.FullPage), Description("Determines the zoom of the page."), Category("Preview Properties")]
    public Zoom Zoom
    {
      get { return (Zoom)this.preview.Zoom; }
      set { this.preview.Zoom = (PdfSharp.Forms.Zoom)value; }
    }

    /// <summary>
    /// Gets or sets an arbitrary zoom factor. The range is from 10 to 800.
    /// </summary>
    //[DefaultValue((int)Zoom.FullPage), Description("Determines the zoom of the page."), Category("Preview Properties")]
    public int ZoomPercent
    {
      get { return this.preview.ZoomPercent; }
      set { this.preview.ZoomPercent = value; }
    }
    int zoomPercent;

    [Description("The background color of the page."), Category("Preview Properties")]
    public Color PageColor
    {
      get { return this.preview.PageColor; }
      set { this.preview.PageColor = value; }
    }
    Color pageColor = Color.GhostWhite;

    [Description("The color of the desktop."), Category("Preview Properties")]
    public Color DesktopColor
    {
      get { return this.preview.DesktopColor; }
      set { this.preview.DesktopColor = value; }
    }
    internal Color desktopColor = SystemColors.ControlDark;

    [DefaultValue(true), Description("Determines whether the scrollbars are visible."), Category("Preview Properties")]
    public bool ShowScrollbars
    {
      get { return this.preview.ShowScrollbars; }
      set { this.preview.ShowScrollbars = value; }
    }
    bool showScrollbars = true;

    [DefaultValue(true), Description("Determines whether the page visible."), Category("Preview Properties")]
    public bool ShowPage
    {
      get { return this.preview.ShowPage; }
      set { this.preview.ShowPage = value; }
    }
    internal bool showPage = true;

    /// <summary>
    /// Gets or sets the page size in point.
    /// </summary>
    [Description("Determines the size (in points) of the page."), Category("Preview Properties")]
    public Size PageSize
    {
      get { return this.preview.PageSize; }
      set { this.preview.PageSize = value; }
    }

    #region Component Designer generated code
    /// <summary> 
    /// Required method for Designer support - do not modify 
    /// the contents of this method with the code editor.
    /// </summary>
    private void InitializeComponent()
    {
      this.preview = new PdfSharp.Forms.PagePreview();
      this.SuspendLayout();
      // 
      // preview
      // 
      this.preview.BorderStyle = System.Windows.Forms.BorderStyle.Fixed3D;
      this.preview.DesktopColor = System.Drawing.SystemColors.ControlDark;
      this.preview.Dock = System.Windows.Forms.DockStyle.Fill;
      this.preview.Location = new System.Drawing.Point(0, 0);
      this.preview.Name = "preview";
      this.preview.PageColor = System.Drawing.Color.GhostWhite;
      this.preview.PageSize = new System.Drawing.Size(595, 842);
      this.preview.Size = new System.Drawing.Size(200, 200);
      this.preview.TabIndex = 0;
      this.preview.Zoom = PdfSharp.Forms.Zoom.FullPage;
      this.preview.ZoomPercent = 15;
      // 
      // PagePreview
      // 
      this.Controls.Add(this.preview);
      this.Name = "PagePreview";
      this.Size = new System.Drawing.Size(200, 200);
      this.ResumeLayout(false);

    }
    #endregion
  }
}
