using System;
using System.Diagnostics;
using MigraDoc.DocumentObjectModel;
using MigraDoc.Rendering;

namespace Invoice
{
  /// <summary>
  /// This sample shows how to create a simple invoice of a fictional book store. The invoice document
  /// is created with the MigraDoc document object model and then rendered to PDF with PDFsharp.
  /// </summary>
  class Programm
  {
    [STAThread]
    static void Main(string[] args)
    {
      // Create a bill form with the sample invoice data
      InvoiceForm bill = new InvoiceForm("../../invoice.xml");

      // Create a MigraDoc document
      Document document = bill.CreateDocument();

#if DEBUG
      // for debugging only...
      MigraDoc.DocumentObjectModel.IO.DdlWriter.WriteToFile(document, "MigraDoc.mdddl");
#endif

      // Create a renderer for PDF
      PdfPrinter printer = new PdfPrinter();

      // Set the MigraDoc document
      printer.Document = document;

      // Create the PDF document
      printer.PrintDocument();

      // Save the PDF document...
      string filename = "Invoice.pdf";
#if DEBUG
      // I dont want to close the document constantly...
      filename = "Invoice-" + Guid.NewGuid().ToString("N").ToUpper() + ".pdf";
#endif
      printer.Save(filename);
      // ...and start a viewer.
      Process.Start(filename);
    }
  }
}
