//
// PDFsharp - A library for processing PDF
//
// Authors:
//   Stefan Lange (mailto:Stefan.Lange@pdfsharp.com)
//
// Copyright (c) 2005 empira Software GmbH, Cologne (Germany)
//
// http://www.pdfsharp.com
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

using System;
using System.Collections;
using System.Globalization;
using System.Text;
using System.IO;
using PdfSharp.Internal;
using PdfSharp.Pdf.IO;
using PdfSharp.Pdf.Internal;

namespace PdfSharp.Pdf
{
  /// <summary>
  /// Represents text that is written 'as it is' into the PDF stream.
  /// </summary>
  public sealed class PdfRawItem : PdfItem
  {
    // TODO: PdfRawValue
    public PdfRawItem()
    {
    }

    /// <summary>
    /// Initializes a new instance with the specified string.
    /// </summary>
    public PdfRawItem(string value)
    {
      this.value = value;
    }

    /// <summary>
    /// Initializes a new instance with the culture invariant formatted specified arguments.
    /// </summary>
    public PdfRawItem(string format, params object[] args)
    {
      this.value = PdfEncoders.Format(format, args);
    }

    public string Value
    {
      // This class must behave like a value type. Therefore it cannot be changed (like System.String).
      get {return this.value;}
    }
    string value = "";

    public override string ToString()
    {
      return this.value;
    }

    internal override void WriteObject(PdfWriter writer)
    {
      writer.Write(this);
    }
  }
}
